<?php
/*
 * Model Class for interacting with the zips database
 */

 // include password file that lives outside
 // of public_html
require_once('/home/kaa2nx/.mysqlpass.inc.php');

class ZipModel {
    
    //MySQL parameters for connecting
    private static $host = 'localhost';
    private static $user = 'dbuser';
    
    private static $database = 'class_examples';
    
    private $connection;
    
    /*
     * function __construct(): create the model and connect to MySQL
     */
    function __construct() {
        /*
         * The old mysqli:
        //connect
        $this->connection = new mysqli(
            self::$host,
            self::$user,
            MySQLPassword::$password,
            self::$database
        );
        
        if($this->connection->connect_errno != 0) {
            throw new Exception("Could not connect!");
        }
        */
        try {
            $this->connection = new PDO(
                "mysql:host=" . self::$host,
                self::$user,
                MySQLPassword::$password
            );
        } catch (PDOException $e) {
            //connection failed
            throw new Exception('Could not connect!');
        }
        
        if(!$this->connection->query("USE " . self::$database)) {
            // an error occurred
            throw new Exception("could not select DB");
        }
        
    }
    
    /*
     * given a zip code, return the city and state
     */
    function get_city_state($zip) {
        $prepared = $this->connection->prepare(
            "SELECT city,state FROM zips WHERE zipcode = :zip"
        );
        
        if(!$prepared->execute([
            ":zip" => $zip
        ])) {
            // the query failed
            throw new Exception("Query Failed!");
        }
        
        // query succeeded!
        if($prepared->rowCount() != 1) {
            // one row if we have a valid zip
            throw new Exception ("Not a Zip code");
        }
        
        // fetch the result
        return $prepared->fetch();
        
        
        /*
         * the old mysqli
        // sanitizing our input data
        $zip = $this->connection->real_escape_string($zip);
        
        $query =
        "SELECT city,state FROM zips WHERE zipcode=$zip";
        
        // executed the query
        $result = $this->connection->query($query);
        
        if($this->connection->errno != 0) {
            throw new Exception("Query Failed");
        }
        
        // the query succeeded
        if($result->num_rows != 1) {
            throw new Exception ("Not a Zip code");
        }
        
        // return back the result
        return $result->fetch_assoc();
        */
    }
}

?>